/*****************************************************************************\
  dj895_maps2.cpp : Color maps for DJ895

  Copyright (c) 1996 - 2001, Hewlett-Packard Co.
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions
  are met:
  1. Redistributions of source code must retain the above copyright
     notice, this list of conditions and the following disclaimer.
  2. Redistributions in binary form must reproduce the above copyright
     notice, this list of conditions and the following disclaimer in the
     documentation and/or other materials provided with the distribution.
  3. Neither the name of Hewlett-Packard nor the names of its
     contributors may be used to endorse or promote products derived
     from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN
  NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
  TO, PATENT INFRINGEMENT; PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
  ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
\*****************************************************************************/


#include "config.h"

#include "global_types.h"

APDK_BEGIN_NAMESPACE

uint32_t ulMapVENICE_HB_KCMY[ 9*9*9 ]=
{
4074819328UL, 2530213376UL, 1420754432UL,  764542464UL,  477822464UL,  258866688UL,
 124255744UL,   23264768UL,    6422016UL, 4268472064UL, 2576481792UL, 1451818496UL,
 696188416UL,  325975552UL,   90635776UL,   23199232UL,    6422016UL,    5963264UL,
4265913856UL, 3410541056UL, 1582748416UL,  861327104UL,  391568128UL,   38991616UL,
   5499136UL,    5495552UL,    5432320UL, 4264013312UL, 3760827392UL, 2117316096UL,
1094299136UL,  540849920UL,  138000128UL,    3845120UL,    4172800UL,    4302592UL,
4263027968UL, 3541736704UL, 2367658752UL, 1428464896UL,  690402304UL,  304528896UL,
  19510272UL,    2989312UL,    3182848UL, 4262173952UL, 3540884224UL, 2568132864UL,
1729534208UL, 1008117504UL,  437634048UL,  102284800UL,    2073088UL,    2395392UL,
4144206848UL, 3540292608UL, 2634584320UL, 1930137856UL, 1309382912UL,  705408000UL,
 218677504UL,   17740032UL,    1606912UL, 3758130432UL, 3405810176UL, 2768406528UL,
2114159872UL, 1510246912UL,  973444096UL,  503491584UL,   67226368UL,     756992UL,
3355473152UL, 3187702272UL, 2634052352UL, 1761632000UL, 1308645376UL,  855659520UL,
 570449664UL,  318803200UL,      42752UL, 4275270912UL, 2650705152UL, 1241425664UL,
 499696640UL,  178647552UL,    9436672UL,    8060416UL,    7601664UL,    6749696UL,
4270030336UL, 2643103488UL, 1452253696UL,  813809152UL,  376560384UL,   40304128UL,
   6422016UL,    6022144UL,    5886720UL, 4266102016UL, 3360591616UL, 1868010496UL,
1012306944UL,  509124608UL,  123055616UL,    5286912UL,    5351680UL,    5286912UL,
4264200192UL, 3190783488UL, 1966374400UL, 1178043136UL,  624659712UL,  221876480UL,
   3840256UL,    4036096UL,    4300032UL, 4263020544UL, 2971367936UL, 2115991296UL,
1394768896UL,  757433600UL,  354781184UL,   36080896UL,    2852096UL,    3114240UL,
4228614144UL, 2886564352UL, 2198829568UL, 1527936768UL,  957643776UL,  471172352UL,
 135692544UL,    1866752UL,    2257664UL, 3825369344UL, 2801954048UL, 2198040320UL,
1594191104UL, 1124626688UL,  638153984UL,  235502080UL,   17659136UL,    1469696UL,
3288363264UL, 2566939136UL, 2197840384UL, 1728079360UL, 1291872000UL,  805398784UL,
 436301056UL,   84047104UL,     681728UL, 3070257408UL, 2566938112UL, 2315280128UL,
1862295808UL, 1442865408UL, 1040212224UL,  654336512UL,  302016768UL,      29440UL,
4276114944UL, 2852018688UL, 1375623680UL,  618949888UL,  196379904UL,   10328832UL,
   9547264UL,    8769280UL,    7599872UL, 4270939648UL, 3130285312UL, 1654807040UL,
 848390400UL,  394623488UL,   24807424UL,    7180544UL,    6922240UL,    6400256UL,
4266875392UL, 3545716992UL, 1969055232UL, 1012295424UL,  525826560UL,  122849280UL,
   5148416UL,    5148928UL,    5083392UL, 4264386304UL, 3123863296UL, 1966366464UL,
1194877440UL,  658270976UL,  238711552UL,    3833344UL,    3965184UL,    4098048UL,
4263142912UL, 2887605760UL, 2115984896UL, 1377984768UL,  757360384UL,  354707200UL,
  36007168UL,    2781440UL,    3110144UL, 3909905152UL, 2769117440UL, 2081251072UL,
1427136256UL,  890461952UL,  454254848UL,  135553536UL,    1662720UL,    2187776UL,
3540150528UL, 2684443904UL, 2080463104UL, 1493326336UL, 1023695360UL,  604396032UL,
 218586368UL,   17521920UL,    1334016UL, 3019923200UL, 2432717824UL, 2046841600UL,
1560302592UL, 1174426880UL,  738219008UL,  402675456UL,   67197440UL,     611840UL,
2885704192UL, 2399163136UL, 2046841088UL, 1677742592UL, 1325421056UL,  973099520UL,
 637555456UL,  302011392UL,      22528UL, 4276369664UL, 3036429312UL, 1543388928UL,
 788414720UL,  281760256UL,   28205568UL,   10056960UL,    9538816UL,    8493824UL,
4271128064UL, 3079750656UL, 1737901312UL, 1049905152UL,  462246656UL,   42294016UL,
   8153344UL,    7435520UL,    6585344UL, 4267065600UL, 3076080896UL, 1834501632UL,
1096501248UL,  526274304UL,  106780160UL,    5922304UL,    5794048UL,    5336320UL,
4264771584UL, 3073918464UL, 2000242432UL, 1262439424UL,  692015360UL,  255612672UL,
  20668160UL,    3892736UL,    4025088UL, 4263332096UL, 2887731200UL, 2116110592UL,
1411664640UL,  791039744UL,  371609344UL,   36131840UL,    2840832UL,    3104512UL,
3758968832UL, 2769177088UL, 2047756544UL, 1410353664UL,  890456832UL,  454315008UL,
 135614208UL,    1724928UL,    2249984UL, 3355661056UL, 2634173184UL, 2046969856UL,
1459832832UL,  973359360UL,  587614464UL,  235359232UL,   17517824UL,    1330688UL,
2919256320UL, 2399159808UL, 1929397248UL, 1476412672UL, 1090536704UL,  721437952UL,
 402671616UL,   67193344UL,     542976UL, 2768260608UL, 2365605632UL, 1929397248UL,
1560298496UL, 1224754176UL,  905986816UL,  603997184UL,  302007808UL,      18176UL,
4275249664UL, 3202622464UL, 1810704128UL, 1005726208UL,  552152064UL,  113523712UL,
  10965248UL,   10183680UL,    9072384UL, 4270794240UL, 2928290048UL, 1905536256UL,
1167339776UL,  630797056UL,  143735808UL,    8932864UL,    7689728UL,    7299328UL,
4267321856UL, 2925210880UL, 1901932288UL, 1214329344UL,  644297984UL,  157694720UL,
   6375168UL,    5984256UL,    5789440UL, 4231605504UL, 2805739264UL, 1967075328UL,
1346581248UL,  709309696UL,  239483136UL,    4538880UL,    4540928UL,    4477184UL,
4263586560UL, 2888052480UL, 2166764032UL, 1462252544UL,  841560832UL,  388577536UL,
  53034752UL,    2836224UL,    3099904UL, 3977261568UL, 2802921728UL, 2115056128UL,
1427321856UL,  907359232UL,  487995136UL,  135805440UL,    1851392UL,    2246400UL,
3355785472UL, 2600744448UL, 2047096064UL, 1443116032UL,  956642304UL,  587675392UL,
 235419904UL,   17579264UL,    1327104UL, 3019915264UL, 2365601792UL, 1929393664UL,
1459631360UL, 1056978176UL,  704656640UL,  385890304UL,   67188992UL,     473600UL,
2684370944UL, 2231384576UL, 1862285056UL, 1493186048UL, 1157641984UL,  838874368UL,
 587216128UL,  302003712UL,      14592UL, 4275508224UL, 3488158976UL, 2130122240UL,
1190599168UL,  704060672UL,  368517120UL,   63450368UL,   11289344UL,   10180096UL,
4271117824UL, 2978814208UL, 2089884416UL, 1251221248UL,  714678528UL,  379265792UL,
  43068672UL,    8601344UL,    8015616UL, 4267645440UL, 2891848704UL, 2002853376UL,
1298210560UL,  711533056UL,  325788672UL,   23538944UL,    6438144UL,    6244352UL,
3913162240UL, 2772377344UL, 1967267840UL, 1346576896UL,  776479744UL,  340403200UL,
  21769216UL,    4929536UL,    4800512UL, 3542491136UL, 2636587264UL, 1999184384UL,
1395335936UL,  841688064UL,  405742592UL,   36710656UL,    3354880UL,    3422464UL,
4145356288UL, 2836734208UL, 2115379712UL, 1427514112UL,  957883392UL,  538649088UL,
 135997696UL,    1978112UL,    2373376UL, 3909624832UL, 2768708352UL, 2080777216UL,
1443243008UL,  973546496UL,  604579328UL,  235612416UL,     929024UL,    1389056UL,
3472960256UL, 2566924288UL, 1895835392UL, 1442850560UL, 1056974592UL,  687876096UL,
 369109248UL,   67185152UL,     535808UL, 2768252928UL, 2231381248UL, 1795173120UL,
1459628544UL, 1157638912UL,  788539648UL,  553658624UL,  268445952UL,      11008UL,
4275243520UL, 3841395200UL, 2415790592UL, 1342049024UL,  704515584UL,  385748736UL,
 167646208UL,   32318464UL,   11613952UL, 4271246080UL, 3079605248UL, 2173766912UL,
1436094208UL,  765268480UL,  463606784UL,  228595200UL,   26485760UL,    9057536UL,
4267970048UL, 2892041984UL, 1935609344UL, 1399066624UL,  761991936UL,  376247296UL,
 107812352UL,    7152640UL,    6763520UL, 3829666048UL, 2722304512UL, 1967395328UL,
1346704128UL,  826938368UL,  407573760UL,   89069056UL,    5186304UL,    5189632UL,
3542750208UL, 2603160576UL, 1965757440UL, 1361908992UL,  858658048UL,  472978944UL,
 104208384UL,    3744256UL,    3812352UL, 3608745216UL, 2484671744UL, 1830360320UL,
1343821056UL,  924587520UL,  538842624UL,  153229312UL,    2366976UL,    2697216UL,
4262138624UL, 2768901120UL, 1997149440UL, 1443566848UL, 1007359488UL,  621549568UL,
 336598528UL,    1187072UL,    1582336UL, 4261550080UL, 2717980416UL, 1962940416UL,
1459624192UL, 1073748480UL,  687872512UL,  352393728UL,   50470144UL,     663808UL,
3238010880UL, 2315263744UL, 1761615616UL, 1426071552UL, 1124081664UL,  771759616UL,
 503324160UL,  251665920UL,       8192UL, 4274521088UL, 4278059520UL, 2851996160UL,
1576927488UL,  670957824UL,  285082368UL,   83756032UL,   33425664UL,   15865856UL,
4271571968UL, 3079734016UL, 2325283584UL, 1604453376UL,  900269312UL,  531171328UL,
 313395456UL,  178719744UL,    9836032UL, 4268557568UL, 2892367104UL, 2087060480UL,
1500185600UL,  930153728UL,  477300736UL,  192350208UL,   58002176UL,    7412480UL,
4148758016UL, 2806384384UL, 2001143296UL, 1397294592UL,  944571904UL,  474875904UL,
 139593728UL,    5508096UL,    5380864UL, 3677161728UL, 2603354368UL, 1932331008UL,
1362036736UL,  892340224UL,  523503616UL,  137955328UL,    3869952UL,    4201472UL,
3759934208UL, 2518354688UL, 1830488576UL, 1327302912UL,  908003840UL,  555813376UL,
 186911232UL,    2756352UL,    2956032UL, 3909946368UL, 2399931136UL, 1728842496UL,
1326254848UL,  940444416UL,  605096704UL,  269748992UL,    1576448UL,    1906688UL,
4261677312UL, 2801993984UL, 1996622336UL, 1476528896UL, 1073875712UL,  687999744UL,
 369363968UL,  134613504UL,     791552UL, 4261416448UL, 2600472320UL, 1862275072UL,
1426067968UL, 1124078336UL,  754979584UL,  486543872UL,  234885376UL,       4608UL,
4275503104UL, 4277600256UL, 3204317184UL, 1946025984UL, 1040056320UL,  486408192UL,
 184418304UL,   83755008UL,   16646144UL, 4271243264UL, 3365142528UL, 2610757632UL,
1974206464UL, 1253703680UL,  617545728UL,  349110272UL,  231407616UL,   12648448UL,
4268687360UL, 3026780160UL, 2238382080UL, 1651310592UL, 1182072832UL,  612237312UL,
 327221248UL,  176226304UL,    8126464UL, 3829989376UL, 2840133632UL, 2118778880UL,
1481375744UL, 1078853632UL,  609288192UL,  240517120UL,   72941568UL,    5832704UL,
3073048576UL, 2687303680UL, 1999568896UL, 1395720192UL,  959578112UL,  607518720UL,
 238747648UL,   21037056UL,    4718592UL, 2719350784UL, 2316959744UL, 1797062656UL,
1344143360UL,  908132352UL,  572653568UL,  254148608UL,   19595264UL,    3473408UL,
2567307264UL, 1963458560UL, 1561001984UL, 1259143168UL,  923795456UL,  605224960UL,
 286654464UL,   18481152UL,    2359296UL, 3288334336UL, 2281766912UL, 1627521024UL,
1275199488UL,  922943488UL,  604307456UL,  352780288UL,   50987008UL,    1179648UL,
4261412864UL, 3019898880UL, 2080374784UL, 1560281088UL, 1207959552UL,  838860800UL,
 536870912UL,  234881024UL,          0
};
/*** Version Info ***/
//{
//     942280052UL,       /* Date (UTC Format) (Local Time : Wed Nov 10 04:27:32 PM */
//     1UL,                       /* Resource Type - color map      */
//     0UL,                       /* Footer Type  0/1 (rel/debug    */
//     kHPVeniceUL,                       /* Product Name                   */
//     kHPHomerUL,                       /* media Name                     */
//     kHPBestModeUL,                       /* Quality Name                   */
//     0UL,                       /* Color Mapper Tool Version      */
//     1UL,                       /* Map Version                    */
//     kHP9CubedUL,                       /* Map Type                       */
//     0UL,                       /* BrkPt Table Resource Number    */
//     kHP6x6UL,                       /* Color Resolution               */
//     kHP6x6                        /* Black Resolution               */
//   }


uint32_t ulMapVENICE_Binary_KCMY[ 9*9*9 ]=
{
1819176648UL,   64158794UL,   80805158UL,   80215318UL,   62389519UL,   61406730UL,
  60292615UL,   42401028UL,    7601920UL, 4230922301UL,  571406681UL,  160889651UL,
 113048859UL,   62717200UL,   45415944UL,   27917573UL,   10419457UL,    9238272UL,
4248940557UL, 3743081259UL,  790296119UL,  325515810UL,  127007505UL,   27196678UL,
  10483712UL,   10286592UL,    9628672UL, 4248283651UL, 4214473229UL, 2871125529UL,
1077076501UL,  592700938UL,  275180291UL,    7331584UL,    8312576UL,    8770816UL,
4247430912UL, 4247433730UL, 3978417159UL, 2317998598UL, 1111022339UL,  524081152UL,
 172217600UL,    5293312UL,    6668032UL, 4263158272UL, 4246448128UL, 4195927810UL,
3021655296UL, 1747244032UL,  858642176UL,  338350592UL,   53332736UL,    4176640UL,
4245529856UL, 4245661184UL, 4195203328UL, 3406608128UL, 2181939712UL, 1108266752UL,
 488232192UL,  135910656UL,    2344448UL, 4278233344UL, 4194346240UL, 4160794112UL,
3691491584UL, 2701570560UL, 1661192448UL,  772069888UL,  286188288UL,    1039104UL,
4278236928UL, 4278234368UL, 4278234624UL, 3842026752UL, 3070273792UL, 2214639616UL,
1325453056UL,  604038400UL,      65280UL, 3422292824UL,  570249275UL,  234730018UL,
 117300502UL,  133429773UL,   64748809UL,   13040645UL,   11859712UL,    9952512UL,
4252725022UL, 1819700817UL,  315878447UL,  131267353UL,   63241741UL,   45481478UL,
  11140354UL,    9961216UL,    8514560UL, 4233722368UL, 4031032611UL, 1430764332UL,
 713808663UL,  178123020UL,   27261699UL,   10089728UL,    9497600UL,    8577280UL,
4248534272UL, 4231900167UL, 3427192076UL, 1565246476UL,  862178052UL,  309054976UL,
   7195648UL,    8047360UL,    8178944UL, 4280780288UL, 4247430912UL, 3911826179UL,
2469969152UL, 1380369664UL,  625064704UL,  172013056UL,    5156608UL,    6468864UL,
4279732480UL, 4245854464UL, 3994202112UL, 2719262208UL, 1545120512UL,  706719232UL,
 304261888UL,    2598400UL,    3974656UL, 4245326336UL, 4194341376UL, 3791690496UL,
2868942592UL, 1980079616UL, 1024042752UL,  437168128UL,  101885440UL,    2204672UL,
4278225408UL, 3724576256UL, 3372254720UL, 2868938752UL, 2281736960UL, 1442878976UL,
 738239232UL,  201566976UL,     961024UL, 4278227968UL, 3422586112UL, 3204482304UL,
2936047360UL, 2516617216UL, 1912639232UL, 1191223040UL,  587248128UL,      47616UL,
4143384622UL, 1761417770UL,  570245662UL,  285052180UL,  100517646UL,   65927685UL,
  15659008UL,   13556992UL,   11649792UL, 4255794442UL, 3117885236UL,  619931177UL,
 251246867UL,  183889409UL,   14611712UL,   13038080UL,   11658752UL,    9819648UL,
4250947840UL, 4152519951UL, 2223998487UL, 1539817476UL,  565827328UL,   10543872UL,
   9888000UL,    9035264UL,    7918848UL, 4248655360UL, 4249843456UL, 3360984842UL,
2222566402UL,  930062592UL,  258780928UL,    7255808UL,    7716608UL,    7455488UL,
4264058368UL, 4247484160UL, 3727922432UL, 2335476992UL, 1211929344UL,  557683456UL,
 121673472UL,    5152000UL,    6138112UL, 4279920640UL, 4262820096UL, 3641935104UL,
2534834944UL, 1578993664UL,  757041664UL,  304252928UL,    2657280UL,    4035584UL,
4278807552UL, 4194333696UL, 3489691904UL, 2583721728UL, 1795586560UL,  990347520UL,
 420250624UL,   85034496UL,    2132224UL, 4278219008UL, 3691014144UL, 3036703744UL,
2566942464UL, 2013294848UL, 1308652800UL,  704676096UL,  184583424UL,     755712UL,
4194334208UL, 3338692864UL, 2868931840UL, 2566942720UL, 2181066752UL, 1694527744UL,
1107328000UL,  570461184UL,      36608UL, 4259653128UL, 2868776476UL, 1190993687UL,
 587021071UL,  217936651UL,   33203202UL,   15841280UL,   14333184UL,   12625664UL,
4273417220UL, 3891139612UL, 1442324508UL,  502942735UL,  133794818UL,   15248640UL,
  14334976UL,   13419264UL,   11713280UL, 4269093632UL, 4221780741UL, 3100072454UL,
1304584967UL,  415074560UL,   11444992UL,   11319552UL,   10601216UL,    9486080UL,
4265819136UL, 4250684928UL, 3480444418UL, 1954444800UL,  913862912UL,  292718592UL,
   7248640UL,    7515648UL,    7255296UL, 4247405312UL, 4247801344UL, 3711721984UL,
2403362048UL, 1296262912UL,  574975488UL,  105150208UL,    5212160UL,    5806592UL,
4263201280UL, 4263203328UL, 3709623808UL, 2552128512UL, 1579180800UL,  790914560UL,
 287729920UL,    2912512UL,    4161280UL, 4245310976UL, 4228207872UL, 3489682688UL,
2550422784UL, 1745378816UL, 1007378688UL,  420373760UL,   68315136UL,    2191872UL,
4278211584UL, 3825226240UL, 3103806464UL, 2499828736UL, 1929403904UL, 1308646912UL,
 687891200UL,  167798016UL,     682752UL, 4160772864UL, 3405795840UL, 2885703424UL,
2449497600UL, 2097176832UL, 1610637568UL, 1073767168UL,  553675776UL,      28160UL,
4276100357UL, 3590196752UL, 1912410896UL,  972890377UL,  519910147UL,   49830913UL,
  15697664UL,   14455808UL,   13077504UL, 4257226242UL, 4159906309UL, 2264535568UL,
 955917063UL,  318322689UL,   15294720UL,   14451968UL,   13932288UL,   12818688UL,
4287243264UL, 4256376834UL, 3403102720UL, 1607350274UL,  617432320UL,   12148224UL,
  12288512UL,   12163584UL,   11313920UL, 4283377152UL, 4268043520UL, 3582212864UL,
2004891648UL,  897729280UL,  243160832UL,    8483840UL,    8752896UL,    8429056UL,
4264307712UL, 4265096192UL, 3695459841UL, 2387099392UL, 1196049920UL,  558648576UL,
  88759296UL,    5469440UL,    5802496UL, 4280169472UL, 4263459072UL, 3659611904UL,
2569158912UL, 1596409088UL,  824788992UL,  288050432UL,    3233792UL,    4222208UL,
4245371648UL, 4228463872UL, 3590995712UL, 2634694912UL, 1762477056UL, 1024476672UL,
 454183424UL,   68439296UL,    2448128UL, 4278206208UL, 3909106944UL, 3238018560UL,
2566931200UL, 1912621056UL, 1275086848UL,  687885056UL,  184569088UL,     742400UL,
4043326464UL, 3372236288UL, 2902475008UL, 2499823360UL, 2063618048UL, 1560301824UL,
1090539776UL,  570447104UL,      22016UL, 4275835907UL, 4043119616UL, 2784892929UL,
1375606275UL,  654187008UL,  184294912UL,   15746304UL,   14379264UL,   13202688UL,
4274394113UL, 4227209216UL, 3053196800UL, 1375344384UL,  402265856UL,   15737600UL,
  14305536UL,   13790208UL,   12941568UL, 4271446016UL, 4223538689UL, 3234600704UL,
1707743744UL,  684662528UL,   63252480UL,   12668160UL,   12545024UL,   12024832UL,
4284291584UL, 4268891136UL, 3448184064UL, 2038897664UL,  948707584UL,  260909824UL,
   9258496UL,    9987840UL,    9993984UL, 4281867264UL, 4265615360UL, 3628737280UL,
2370708224UL, 1330915328UL,  542519040UL,   55852544UL,    6576640UL,    7042048UL,
4280427008UL, 4247004160UL, 3643155456UL, 2502436096UL, 1563240960UL,  741222912UL,
 271660032UL,    3556608UL,    4480768UL, 4279182848UL, 4212074240UL, 3507431424UL,
2601462272UL, 1746021376UL, 1007955712UL,  454373888UL,   51852800UL,    2705664UL,
4278201344UL, 3942656768UL, 3238013696UL, 2583702528UL, 1912614912UL, 1174417920UL,
 620770048UL,  151008256UL,     868352UL, 3724555008UL, 3221237504UL, 2818584320UL,
2449486592UL, 2030057728UL, 1543519744UL, 1056980992UL,  570441984UL,      16896UL,
4258860033UL, 4160293632UL, 3170699520UL, 1660750336UL,  738069248UL,  201198336UL,
  16256768UL,   14824960UL,   13522176UL, 4257745665UL, 4226745857UL, 3220308480UL,
1609499648UL,  535758592UL,   15403264UL,   14752256UL,   13843200UL,   13261056UL,
4255321344UL, 4173399296UL, 3082880256UL, 1841497856UL,  751176192UL,   79956480UL,
  12853248UL,   12795904UL,   12475136UL, 4251717120UL, 4219341568UL, 3213428736UL,
2055866880UL, 1016007936UL,  261426944UL,   10166016UL,   10698496UL,   10705408UL,
4282454272UL, 4249227520UL, 3477868032UL, 2337542144UL, 1331368192UL,  576591360UL,
  73473536UL,    7486464UL,    8279552UL, 4280685824UL, 4230419968UL, 3525972992UL,
2519602176UL, 1580537344UL,  825628672UL,  255401472UL,    4337920UL,    5458688UL,
4279637504UL, 4212528640UL, 3423737088UL, 2584942080UL, 1746343424UL,  957945344UL,
 505355520UL,   35529472UL,    3095296UL, 4194309888UL, 3959429376UL, 3271563520UL,
2566920704UL, 1845500416UL, 1174674944UL,  637870080UL,  218571008UL,    1191424UL,
3573555968UL, 3103793408UL, 2734694656UL, 2365596160UL, 1962943744UL, 1476405248UL,
 989867008UL,  536882176UL,      11776UL, 4208197632UL, 4227006464UL, 3489595392UL,
2113536000UL,  955777024UL,  419169024UL,   50135552UL,   16059136UL,   14298112UL,
4291166208UL, 3973513216UL, 3151429632UL, 2044329984UL,  903675904UL,  266272768UL,
  14616064UL,   14160384UL,   13512448UL, 4289003520UL, 3836936192UL, 2930966528UL,
2109145088UL, 1018953728UL,  314572800UL,   12649984UL,   12916480UL,   12793088UL,
4201906176UL, 3900702720UL, 2978611200UL, 2139881472UL, 1217462272UL,  429260800UL,
  10159104UL,   11148032UL,   11417600UL, 4249355008UL, 4081647616UL, 3209887744UL,
2254045184UL, 1365114880UL,  627311104UL,   74056704UL,    8198912UL,    8992768UL,
4247389696UL, 4180346112UL, 3425633280UL, 2486436864UL, 1631192064UL,  842925568UL,
 272631808UL,    4986880UL,    6305024UL, 4279634432UL, 4145482496UL, 3356952576UL,
2585331456UL, 1780287488UL, 1008732416UL,  472124416UL,    2363392UL,    3746560UL,
4245097216UL, 4043770880UL, 3338996224UL, 2634353408UL, 1913064192UL, 1191709696UL,
 621481216UL,  370546176UL,    1646080UL, 3825209856UL, 3338670592UL, 2868908800UL,
2365592320UL, 1946162176UL, 1426068480UL,  939529728UL,  503322368UL,       6400UL,
4293197824UL, 4226744320UL, 3639410688UL, 2582380544UL, 1475215360UL,  753991680UL,
 318111744UL,  100204544UL,   16711680UL, 4223860736UL, 3602972672UL, 3049521152UL,
2362048512UL, 1406140416UL,  684982272UL,  265814016UL,   14352384UL,   14417920UL,
4020436992UL, 3483893760UL, 2896822272UL, 2309947392UL, 1488191488UL,  733544448UL,
 280756224UL,   12713984UL,   13041664UL, 3799646208UL, 3431137280UL, 2878078976UL,
2291204096UL, 1586757632UL,  832176128UL,  312279040UL,   10878976UL,   11665408UL,
3763470336UL, 3394633728UL, 2908749824UL, 2288648192UL, 1651310592UL,  963706880UL,
 360054784UL,    8323072UL,    9634560UL, 3912433664UL, 3442802688UL, 2956591104UL,
2403467264UL, 1766326272UL, 1078722560UL,  474873856UL,    5505024UL,    7013632UL,
4162584576UL, 3692888064UL, 3005218816UL, 2418212864UL, 1881604096UL, 1194065920UL,
 590348288UL,  120782848UL,    4457216UL, 4278779904UL, 3959422976UL, 3255238656UL,
2617769984UL, 1980366848UL, 1292828672UL,  672202752UL,  236126208UL,    2228224UL,
4278190080UL, 3657433088UL, 3120562176UL, 2634022912UL, 2030043136UL, 1493172224UL,
 905969664UL,  402653184UL,          0
};

APDK_END_NAMESPACE

/*** Version Info ***/
//     951950817UL,       /* Date (UTC Format) (Local Time : Wed Mar 01 02:46:57 PM */
//     1UL,                       /* Resource Type - color map      */
//     0UL,                       /* Footer Type  0/1 (rel/debug    */
//     kHPVeniceUL,                       /* Product Name                   */
//     kHPPlainUL,                       /* media Name                     */
//     KHPDraftModeUL,                       /* Quality Name                   */
//     1UL,                       /* Color Mapper Tool Version      */
//     1UL,                       /* Map Version                    */
//     kHP9CubedUL,                       /* Map Type                       */
//     0UL,                       /* BrkPt Table Resource Number    */
//     kHP3x3UL,                       /* Color Resolution               */
//     kHP3x3UL,                       /* Black Resolution               */
//     0                         /* Spare 32 bit                   */
